@@ -8,7 +8,7 @@ from flexget.options import get_parser
 from flexget import plugin
 from flexget.manager import Manager
 
-__version__ = '1.2.161'
+__version__ = '1.2.162'
 
 log = logging.getLogger('main')
 
@@ -35,7 +35,7 @@ def main(args=None):
             import cProfile as profile
         except ImportError:
             import profile
-        profile.runctx('manager.run_cli_command()', globals(), locals(),
+        profile.runctx('manager.start()', globals(), locals(),
                        os.path.join(manager.config_base, options.profile))
     else:
-        manager.run_cli_command()
+        manager.start()
