@@ -7,8 +7,7 @@ import threading
 import rpyc
 from rpyc.utils.server import ThreadedServer
 
-from flexget.scheduler import BufferQueue
-from flexget.utils.tools import console
+from flexget.utils.tools import BufferQueue, console
 
 log = logging.getLogger('ipc')
 
@@ -32,12 +31,12 @@ class DaemonService(rpyc.Service):
         # Dictionaries are pass by reference with rpyc, turn this into a real dict on our side
         if options:
             options = rpyc.utils.classic.obtain(options)
-        if self.manager.scheduler.run_queue.qsize() > 0:
+        if len(self.manager.task_queue) > 0:
             self.client_console('There is already a task executing. This task will execute next.')
         log.info('Executing for client.')
         cron = options and options.get('cron')
         output = None if cron else BufferQueue()
-        tasks_finished = self.manager.scheduler.execute(options=options, output=output)
+        tasks_finished = self.manager.execute(options=options, output=output)
         if output:
             # Send back any output until all tasks have finished
             while any(not t.is_set() for t in tasks_finished) or output.qsize():
@@ -57,7 +56,7 @@ class DaemonService(rpyc.Service):
     def exposed_shutdown(self, finish_queue=False):
         log.info('Shutdown requested over ipc.')
         self.client_console('Daemon shutdown requested.')
-        self.manager.scheduler.shutdown(finish_queue=finish_queue)
+        self.manager.shutdown(finish_queue=finish_queue)
 
     def client_console(self, text):
         self._conn.root.console(text)
